==> aroundme_0_7_3.tar.gz: aroundme_0_7_3/aroundme/components/core/language/1/barnraiser_01/common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// USER STATUS
$lang['user_online_status'][1] = 				"online";
$lang['user_online_status'][2] = 				"idle";
$lang['user_online_status'][3] = 				"sleeping";
$lang['user_online_status'][4] = 				"offline";


// MEMBERSHIP TYPES
$lang['membership_type'][1] = 					"honorary";
$lang['membership_type'][2] = 					"active supporter";
$lang['membership_type'][3] = 					"active builder";
$lang['membership_type'][4] = 					"active volunteer";
$lang['membership_type'][5] = 					"sustainer";


// ROLES
$lang['role'][1] = 								"maintainer";
$lang['role'][2] = 								"membership secretary";
$lang['role'][3] = 								"groups coordinator";
$lang['role'][4] = 								"activity coordinator";


// LANGUAGES
$lang['arr_lang_name'][1] = 					"english";
$lang['arr_lang_name'][2] = 					"svensk";


// MODULES
$lang['arr_module'][4] = 						"group";
$lang['arr_module'][5] = 						"blog";
$lang['arr_module'][6] = 						"space";
$lang['arr_module'][3] = 						"wiki";
$lang['arr_module'][2] = 						"project";
$lang['arr_module'][1] = 						"event";

$lang['menu_main_event'] = 						"Events";
$lang['menu_main_group'] = 						"Groups";
$lang['menu_main_library'] = 					"Wiki";
$lang['menu_main_blog'] = 						"Blogs";
$lang['menu_main_project'] = 					"Projects";
$lang['menu_main_space'] = 						"Spaces";



// USER STATISTICS
$lang['statistic']['user'][1] = 				"total logins";


//META TAGS (this will appear in search engines)
$lang['meta_Description'] =						""; //add in a description for your instance
$lang['meta_keywords'] = 						""; //add in up to 25 keywords (a descriptive word for search engines)
$lang['meta_OriginalPublicationDate'] =			"";//YYYY/MM/DD // //add in a publication date


// HEADERS
$lang['hdr_options'] = 							"options";
$lang['hdr_tag_cloud'] = 						"tag cloud";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_add_comment'] = 						"add a comment";
$lang['hdr_comment_preview'] = 					"preview comment";


// HREF (links)
$lang['href_logoff'] = 							"logoff";
$lang['href_report_abuse'] = 					"report abuse";
$lang['href_not_logged_in'] = 					"you are not logged in";
$lang['href_comment_reply'] = 					"reply";


// ERROR MESSAGES
$lang['error']['db_error'] = 					"Database error";
$lang['error']['mail_error'] =					"Mail error.";


// TEMPLATE ERROR MESSAGES
$lang['template_error']['err_no_items'] = 		"Sorry, there are no items to be listed.";


// MENU TEXTS
$lang['menu_main_me'] = 						"Me";
$lang['menu_main_structure'] = 					"Structure";
$lang['menu_main_library'] = 					"Wiki";




// NEXT / PREV PAGE NAV
$lang['txt_list_nav_start'] = 					"start";
$lang['txt_list_nav_end'] = 					"end";
$lang['txt_list_nav_prev'] = 					"previous";
$lang['txt_list_nav_next'] = 					"next";


//BODY TEXT
$lang['txt_page_title'] = 						"AROUNDMe 0.7.x";
$lang['txt_footer'] = 							"AROUNDMe is <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and advance society through social software. Please consider <a href=\"http://www.barnraiser.org/contribute/\">supporting us</a>.";
$lang['txt_mutual'] = 							"mutual";
$lang['txt_help'] = 							"help";
$lang['txt_required'] = 						"required";
$lang['txt_matrix'] = 							"matrix";
$lang['txt_block_warning'] = 					"WARNING You are blocking this person";
$lang['txt_vouched'] = 							"vouched";
$lang['txt_comment_position'] = 				"This comment will be added against the main item.";
$lang['txt_comment_position1'] = 				"This comment will be added against the item marked in blue";
$lang['txt_dated'] = 							"dated";
$lang['txt_from'] = 							"from";
$lang['txt_joined'] = 							"joined";
$lang['txt_location'] = 						"location";

// COMMON SUBMIT BUTTONS
$lang['sub_check_spelling'] = 					"spellcheck";
$lang['sub_preview'] = 							"preview";
$lang['sub_add'] = 								"add";
$lang['sub_edit_again'] = 						"edit again";


// ID CARD
$lang['txt_invitee'] = 							"invitee";


// EMAIL TEXTS
$lang['subject_noreply'] = 						"no reply";

?>

==> aroundme_0_7_4.tar.gz: aroundme_0_7_4/aroundme/components/core/language/1/barnraiser_01/common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// USER STATUS
$lang['user_online_status'][1] = 				"online";
$lang['user_online_status'][2] = 				"idle";
$lang['user_online_status'][3] = 				"sleeping";
$lang['user_online_status'][4] = 				"offline";


// MEMBERSHIP TYPES
$lang['membership_type'][1] = 					"honorary";
$lang['membership_type'][2] = 					"active supporter";
$lang['membership_type'][3] = 					"active builder";
$lang['membership_type'][4] = 					"active volunteer";
$lang['membership_type'][5] = 					"sustainer";


// ROLES
$lang['role'][1] = 								"maintainer";
$lang['role'][2] = 								"membership secretary";
$lang['role'][3] = 								"groups coordinator";
$lang['role'][4] = 								"activity coordinator";


// USER PREFERENCES
$lang['user']['preference'][1] = 	"receive an email when you receive a message.";
$lang['user']['preference'][2] = 	"receive announcements via email.";


// LANGUAGES
$lang['arr_lang_name'][1] = 					"english";


// MODULES



// USER STATISTICS
$lang['statistic']['user'][1] = 				"total logins";


//META TAGS (this will appear in search engines)
$lang['meta_Description'] =						""; //add in a description for your instance
$lang['meta_keywords'] = 						""; //add in up to 25 keywords (a descriptive word for search engines)
$lang['meta_OriginalPublicationDate'] =			"";//YYYY/MM/DD // //add in a publication date


// HEADERS
$lang['hdr_options'] = 							"options";
$lang['hdr_tag_cloud'] = 						"tag cloud";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_add_comment'] = 						"add a comment";
$lang['hdr_comment_preview'] = 					"preview comment";


// HREF (links)
$lang['href_logoff'] = 							"logoff";
$lang['href_report_abuse'] = 					"report abuse";
$lang['href_not_logged_in'] = 					"you are not logged in";
$lang['href_comment_reply'] = 					"reply";


// ERROR MESSAGES
$lang['error']['db_error'] = 					"Database error";
$lang['error']['mail_error'] =					"Mail error.";


// TEMPLATE ERROR MESSAGES
$lang['template_error']['err_no_items'] = 		"Sorry, there are no items to be listed.";


// MENU TEXTS
$lang['menu_main_me'] = 						"Me";
$lang['menu_main_structure'] = 					"Structure";




// NEXT / PREV PAGE NAV
$lang['txt_list_nav_start'] = 					"start";
$lang['txt_list_nav_end'] = 					"end";
$lang['txt_list_nav_prev'] = 					"previous";
$lang['txt_list_nav_next'] = 					"next";


//BODY TEXT
$lang['txt_page_title'] = 						"AROUNDMe 0.7.4";
$lang['txt_footer'] = 							"AROUNDMe is <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and advance society through social software. Please consider <a href=\"http://www.barnraiser.org/contribute/\">supporting us</a>.";
$lang['txt_mutual'] = 							"mutual";
$lang['txt_help'] = 							"help";
$lang['txt_required'] = 						"required";
$lang['txt_matrix'] = 							"matrix";
$lang['txt_block_warning'] = 					"WARNING You are blocking this person";
$lang['txt_vouched'] = 							"vouched";
$lang['txt_comment_position'] = 				"This comment will be added against the main item.";
$lang['txt_comment_position1'] = 				"This comment will be added against the item marked in blue";
$lang['txt_dated'] = 							"dated";
$lang['txt_from'] = 							"from";
$lang['txt_joined'] = 							"joined";
$lang['txt_location'] = 						"location";

// COMMON SUBMIT BUTTONS
$lang['sub_check_spelling'] = 					"spellcheck";
$lang['sub_preview'] = 							"preview";
$lang['sub_add'] = 								"add";
$lang['sub_edit_again'] = 						"edit again";


// ID CARD
$lang['txt_invitee'] = 							"invitee";


// EMAIL TEXTS
$lang['subject_noreply'] = 						"no reply";

?>
